# Copyright 2021 The TensorFlow Recommenders Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Lint-as: python3
"""Layers."""

from tensorflow_recommenders.layers import blocks
from tensorflow_recommenders.layers import embedding
from tensorflow_recommenders.layers import factorized_top_k
from tensorflow_recommenders.layers import feature_interaction
from tensorflow_recommenders.layers import loss
from tensorflow_recommenders.layers.feature_interaction import dcn
